@@ -1,33 +1,38 @@
 from datetime import date
 from unittest.mock import patch
-from django.db.utils import DatabaseError, IntegrityError
-from django.test.testcases import (
-    TestCase,
-    TransactionTestCase as DbTransactionTestCase,
-    TransactionTestCase,
-)
+
 from django.db import transaction as db_transaction
+from django.db.utils import DatabaseError, IntegrityError
+from django.test.testcases import TransactionTestCase as DbTransactionTestCase
 from moneyed.classes import Money
 
-from hordak.models import Account, Transaction, Leg, StatementImport, StatementLine, DEBIT, CREDIT
 from hordak import exceptions
+from hordak.models import (
+    CREDIT,
+    DEBIT,
+    Account,
+    Leg,
+    StatementImport,
+    StatementLine,
+    Transaction,
+)
 from hordak.tests.utils import DataProvider
 from hordak.utilities.currency import Balance
 
 
-class AccountTestCase(DataProvider, TransactionTestCase):
+class AccountTestCase(DataProvider, DbTransactionTestCase):
     def test_str_root(self):
         # Account code should not be rendered as we should not
         # associate transaction legs with non-leaf accounts
         account1 = self.account(name="Account 1", code="5")
-        account2 = self.account(parent=account1, code="1")
+        self.account(parent=account1, code="1")
         self.assertEqual(str(account1), "Account 1")
 
     def test_str_root_no_code(self):
         # Account code should not be rendered as we should not
         # associate transaction legs with non-leaf accounts
         account1 = self.account(name="Account 1")
-        account2 = self.account(parent=account1)
+        self.account(parent=account1)
         self.assertEqual(str(account1), "Account 1")
 
     def test_str_child(self):
@@ -38,11 +43,13 @@ class AccountTestCase(DataProvider, TransactionTestCase):
         with patch("babel.numbers.format_currency", return_value="FORMATTED"):
             # NOTE: We don't want to test the currency formatting. In part because
             # we assume babel has the covered, but also because it will vary with system locale
-            self.assertEqual(str(account2).replace("\xa0", ""), "51 Account 2 [FORMATTED]")
+            self.assertEqual(
+                str(account2).replace("\xa0", ""), "51 Account 2 [FORMATTED]"
+            )
 
     def test_str_root_no_data_unsaved(self):
         account1 = Account()
-        account2 = Account(parent=account1)
+        Account(parent=account1)
         self.assertEqual(str(account1), "Unnamed Account")
 
     def test_str_child_no_data_unsaved(self):
@@ -101,7 +108,9 @@ class AccountTestCase(DataProvider, TransactionTestCase):
         self.assertEqual(trading.sign, 1)
 
         self.assertEqual(
-            len(Account.TYPES), 6, msg="Did not test all account types. Update this test."
+            len(Account.TYPES),
+            6,
+            msg="Did not test all account types. Update this test.",
         )
 
     def test_balance_simple(self):
@@ -110,8 +119,12 @@ class AccountTestCase(DataProvider, TransactionTestCase):
 
         with db_transaction.atomic():
             transaction = Transaction.objects.create()
-            Leg.objects.create(transaction=transaction, account=account1, amount=Money(100, "EUR"))
-            Leg.objects.create(transaction=transaction, account=account2, amount=Money(-100, "EUR"))
+            Leg.objects.create(
+                transaction=transaction, account=account1, amount=Money(100, "EUR")
+            )
+            Leg.objects.create(
+                transaction=transaction, account=account2, amount=Money(-100, "EUR")
+            )
 
         self.assertEqual(account1.simple_balance(), Balance(100, "EUR"))
         self.assertEqual(account2.simple_balance(), Balance(-100, "EUR"))
@@ -123,9 +136,15 @@ class AccountTestCase(DataProvider, TransactionTestCase):
 
         with db_transaction.atomic():
             transaction = Transaction.objects.create()
-            Leg.objects.create(transaction=transaction, account=account1, amount=Money(100, "EUR"))
-            Leg.objects.create(transaction=transaction, account=account2, amount=Money(-40, "EUR"))
-            Leg.objects.create(transaction=transaction, account=account3, amount=Money(-60, "EUR"))
+            Leg.objects.create(
+                transaction=transaction, account=account1, amount=Money(100, "EUR")
+            )
+            Leg.objects.create(
+                transaction=transaction, account=account2, amount=Money(-40, "EUR")
+            )
+            Leg.objects.create(
+                transaction=transaction, account=account3, amount=Money(-60, "EUR")
+            )
 
         self.assertEqual(account1.simple_balance(), Balance(100, "EUR"))
         self.assertEqual(account2.simple_balance(), Balance(-40, "EUR"))
@@ -137,12 +156,20 @@ class AccountTestCase(DataProvider, TransactionTestCase):
 
         with db_transaction.atomic():
             transaction = Transaction.objects.create(date="2016-06-01")
-            Leg.objects.create(transaction=transaction, account=account1, amount=Money(100, "EUR"))
-            Leg.objects.create(transaction=transaction, account=account2, amount=Money(-100, "EUR"))
+            Leg.objects.create(
+                transaction=transaction, account=account1, amount=Money(100, "EUR")
+            )
+            Leg.objects.create(
+                transaction=transaction, account=account2, amount=Money(-100, "EUR")
+            )
 
             transaction = Transaction.objects.create(date="2016-06-15")
-            Leg.objects.create(transaction=transaction, account=account1, amount=Money(50, "EUR"))
-            Leg.objects.create(transaction=transaction, account=account2, amount=Money(-50, "EUR"))
+            Leg.objects.create(
+                transaction=transaction, account=account1, amount=Money(50, "EUR")
+            )
+            Leg.objects.create(
+                transaction=transaction, account=account2, amount=Money(-50, "EUR")
+            )
 
         self.assertEqual(
             account1.simple_balance(as_of="2016-01-01"), Balance(0, "EUR")
@@ -174,21 +201,35 @@ class AccountTestCase(DataProvider, TransactionTestCase):
         with db_transaction.atomic():
             transaction = Transaction.objects.create(date="2016-06-01")
             Leg.objects.create(
-                transaction=transaction, account=account1, amount=100, amount_currency="EUR"
+                transaction=transaction,
+                account=account1,
+                amount=100,
+                amount_currency="EUR",
             )
             Leg.objects.create(
-                transaction=transaction, account=account2, amount=-100, amount_currency="EUR"
+                transaction=transaction,
+                account=account2,
+                amount=-100,
+                amount_currency="EUR",
             )
 
             transaction = Transaction.objects.create(date="2016-06-15")
             Leg.objects.create(
-                transaction=transaction, account=account1, amount=50, amount_currency="EUR"
+                transaction=transaction,
+                account=account1,
+                amount=50,
+                amount_currency="EUR",
             )
             Leg.objects.create(
-                transaction=transaction, account=account2, amount=-50, amount_currency="EUR"
+                transaction=transaction,
+                account=account2,
+                amount=-50,
+                amount_currency="EUR",
             )
 
-        self.assertEqual(account1.balance(transaction__date__gte="2016-06-15"), Balance(50, "EUR"))
+        self.assertEqual(
+            account1.balance(transaction__date__gte="2016-06-15"), Balance(50, "EUR")
+        )
 
     def test_balance(self):
         account1 = self.account(type=Account.TYPES.income)
@@ -198,13 +239,22 @@ class AccountTestCase(DataProvider, TransactionTestCase):
         with db_transaction.atomic():
             transaction = Transaction.objects.create()
             Leg.objects.create(
-                transaction=transaction, account=account1, amount=50, amount_currency="EUR"
+                transaction=transaction,
+                account=account1,
+                amount=50,
+                amount_currency="EUR",
             )
             Leg.objects.create(
-                transaction=transaction, account=account1_child, amount=50, amount_currency="EUR"
+                transaction=transaction,
+                account=account1_child,
+                amount=50,
+                amount_currency="EUR",
             )
             Leg.objects.create(
-                transaction=transaction, account=account2, amount=-100, amount_currency="EUR"
+                transaction=transaction,
+                account=account2,
+                amount=-100,
+                amount_currency="EUR",
             )
 
         self.assertEqual(account1.balance(), Balance(100, "EUR"))
@@ -218,7 +268,8 @@ class AccountTestCase(DataProvider, TransactionTestCase):
         bank.transfer_to(account2, Money(50, "EUR"))
 
         self.assertEqual(
-            Account.objects.filter(type=Account.TYPES.income).net_balance(), Balance(150, "EUR")
+            Account.objects.filter(type=Account.TYPES.income).net_balance(),
+            Balance(150, "EUR"),
         )
 
     def test_zero_balance_single(self):
@@ -316,7 +367,7 @@ class AccountTestCase(DataProvider, TransactionTestCase):
 
     def test_full_code_error_on_non_unique(self):
         account1 = self.account(code="5")
-        account2 = self.account(parent=account1, code="0")
+        self.account(parent=account1, code="0")
 
         with self.assertRaises(DatabaseError):
             self.account(parent=account1, code="0")
@@ -401,11 +452,15 @@ class LegTestCase(DataProvider, DbTransactionTestCase):
             )
 
         self.assertEqual(Leg.objects.sum_to_balance(), Balance())
-        self.assertEqual(account1.legs.sum_to_balance(), Balance([Money("100.12", "USD")]))
-        self.assertEqual(account2.legs.sum_to_balance(), Balance([Money("-100.12", "USD")]))
+        self.assertEqual(
+            account1.legs.sum_to_balance(), Balance([Money("100.12", "USD")])
+        )
+        self.assertEqual(
+            account2.legs.sum_to_balance(), Balance([Money("-100.12", "USD")])
+        )
 
     def test_postgres_trigger_sum_zero(self):
-        """"
+        """ "
         Check the database enforces leg amounts summing to zero
 
         This is enforced by a postgres trigger applied in migration 0005.
@@ -421,8 +476,12 @@ class LegTestCase(DataProvider, DbTransactionTestCase):
 
         with self.assertRaises(DatabaseError), db_transaction.atomic():
             # Also ensure we distinguish between currencies
-            Leg.objects.create(transaction=transaction, account=account, amount=Money(100, "EUR"))
-            Leg.objects.create(transaction=transaction, account=account, amount=Money(-100, "GBP"))
+            Leg.objects.create(
+                transaction=transaction, account=account, amount=Money(100, "EUR")
+            )
+            Leg.objects.create(
+                transaction=transaction, account=account, amount=Money(-100, "GBP")
+            )
 
     def test_postgres_trigger_currency(self):
         """Check the database enforces that leg currencies must be supported by the leg's account"""
@@ -430,8 +489,12 @@ class LegTestCase(DataProvider, DbTransactionTestCase):
         transaction = Transaction.objects.create()
 
         with self.assertRaises(DatabaseError):
-            Leg.objects.create(transaction=transaction, account=account, amount=Money(100, "EUR"))
-            Leg.objects.create(transaction=transaction, account=account, amount=Money(-100, "EUR"))
+            Leg.objects.create(
+                transaction=transaction, account=account, amount=Money(100, "EUR")
+            )
+            Leg.objects.create(
+                transaction=transaction, account=account, amount=Money(-100, "EUR")
+            )
 
     def test_postgres_trigger_bank_accounts_are_asset_accounts(self):
         """Check the database enforces that only asset accounts can be bank accounts"""
@@ -445,8 +508,12 @@ class LegTestCase(DataProvider, DbTransactionTestCase):
 
         with db_transaction.atomic():
             transaction = Transaction.objects.create()
-            leg1 = Leg.objects.create(transaction=transaction, account=account1, amount=100)
-            leg2 = Leg.objects.create(transaction=transaction, account=account2, amount=-100)
+            leg1 = Leg.objects.create(
+                transaction=transaction, account=account1, amount=100
+            )
+            leg2 = Leg.objects.create(
+                transaction=transaction, account=account2, amount=-100
+            )
 
         self.assertEqual(leg1.type, CREDIT)
         self.assertEqual(leg1.is_credit(), True)
@@ -469,8 +536,8 @@ class LegTestCase(DataProvider, DbTransactionTestCase):
 
         with db_transaction.atomic():
             transaction = Transaction.objects.create()
-            leg1 = Leg.objects.create(transaction=transaction, account=account1, amount=100)
-            leg2 = Leg.objects.create(transaction=transaction, account=account2, amount=-100)
+            Leg.objects.create(transaction=transaction, account=account1, amount=100)
+            Leg.objects.create(transaction=transaction, account=account2, amount=-100)
 
         leg3 = Leg(transaction=transaction, account=account2, amount=Money(0, "EUR"))
         self.assertRaises(exceptions.ZeroAmountError, leg3.save)
@@ -482,8 +549,10 @@ class LegTestCase(DataProvider, DbTransactionTestCase):
 
         with db_transaction.atomic():
             transaction = Transaction.objects.create()
-            leg1 = Leg.objects.create(transaction=transaction, account=account1, amount=100)
-            leg2 = Leg.objects.create(transaction=transaction, account=account2, amount=-100)
+            leg1 = Leg.objects.create(
+                transaction=transaction, account=account1, amount=100
+            )
+            Leg.objects.create(transaction=transaction, account=account2, amount=-100)
 
         with self.assertRaises(IntegrityError):
             # Use update() to bypass the check in Leg.save()
@@ -577,8 +646,12 @@ class TransactionTestCase(DataProvider, DbTransactionTestCase):
     def test_balance(self):
         with db_transaction.atomic():
             transaction = Transaction.objects.create()
-            Leg.objects.create(transaction=transaction, account=self.account1, amount=100)
-            Leg.objects.create(transaction=transaction, account=self.account2, amount=-100)
+            Leg.objects.create(
+                transaction=transaction, account=self.account1, amount=100
+            )
+            Leg.objects.create(
+                transaction=transaction, account=self.account2, amount=-100
+            )
 
         self.assertEqual(transaction.balance(), 0)
 
@@ -589,13 +662,19 @@ class TransactionTestCase(DataProvider, DbTransactionTestCase):
 
 class StatementLineTestCase(DataProvider, DbTransactionTestCase):
     def setUp(self):
-        self.bank = self.account(name="Bank", type=Account.TYPES.asset, currencies=["EUR"])
-        self.sales = self.account(name="Sales", type=Account.TYPES.income, currencies=["EUR"])
+        self.bank = self.account(
+            name="Bank", type=Account.TYPES.asset, currencies=["EUR"]
+        )
+        self.sales = self.account(
+            name="Sales", type=Account.TYPES.income, currencies=["EUR"]
+        )
         self.expenses = self.account(
             name="Expenses", type=Account.TYPES.expense, currencies=["EUR"]
         )
 
-        self.statement_import = StatementImport.objects.create(bank_account=self.bank, source="csv")
+        self.statement_import = StatementImport.objects.create(
+            bank_account=self.bank, source="csv"
+        )
 
     def test_is_reconciled(self):
         line = StatementLine.objects.create(
